import { Toaster } from "@/components/ui/toaster";
import { Toaster as Sonner } from "@/components/ui/sonner";
import { TooltipProvider } from "@/components/ui/tooltip";
import { QueryClient, QueryClientProvider } from "@tanstack/react-query";
import { Routes, Route, BrowserRouter } from "react-router-dom";
import { ThemeProvider } from "./components/ThemeProvider";
import ScrollToTop from "./components/ScrollToTop";
import GlobalPasteHandler from "./components/GlobalPasteHandler";
import TawkChatWidget from "./components/TawkChatWidget";
import FaqAiAgent from "./components/FaqAiAgent";
import { Suspense, lazy } from "react";

// Lazy load critical pages first
import Index from "./pages/Index";
import GetQuote from "./pages/GetQuote";

// Lazy load non-critical pages for better performance
const AboutUs = lazy(() => import("./pages/AboutUs"));
const ContactUs = lazy(() => import("./pages/ContactUs"));
const Security = lazy(() => import("./pages/Security"));

const WebsiteSecurityScan = lazy(() => import("./pages/WebsiteSecurityScan"));
const EmailBreachCheck = lazy(() => import("./pages/EmailBreachCheck"));
const BrowserExtension = lazy(() => import("./pages/BrowserExtension"));
const NotFound = lazy(() => import("./pages/NotFound"));
const PrivacyPolicy = lazy(() => import("./pages/PrivacyPolicy"));
const TermsOfUse = lazy(() => import("./pages/TermsOfUse"));
const RefundPolicy = lazy(() => import("./pages/RefundPolicy"));
const CookiesPolicy = lazy(() => import("./pages/CookiesPolicy"));
const DMCA = lazy(() => import("./pages/DMCA"));
const DoNotCallPolicy = lazy(() => import("./pages/DoNotCallPolicy"));
const UserDataDeletion = lazy(() => import("./pages/UserDataDeletion"));
import HomePlans from "./pages/HomePlans";
import BusinessPlans from "./pages/BusinessPlans";
import WebsitePlans from "./pages/WebsitePlans";
import HomeDeviceSupport from "./pages/HomeDeviceSupport";
import SmallBusinessSupport from "./pages/SmallBusinessSupport";
import WebsiteSupport from "./pages/WebsiteSupport";
import ComputerSelectionServices from "./pages/ComputerSelectionServices";
import DeviceUpgrade from "./pages/DeviceUpgrade";
import Microsoft365Solutions from "./pages/Microsoft365Solutions";
import CloudServices from "./pages/CloudServices";
import DigitalWebsiteSolutions from "./pages/DigitalWebsiteSolutions";
import AiServices from "./pages/AiServices";
import AiResumeGenerator from "./pages/AiResumeGenerator";
import AiCaptionGenerator from "./pages/AiCaptionGenerator";
import AiVideoRepurposing from "./pages/AiVideoRepurposing";
import AiLeadGeneration from "./pages/AiLeadGeneration";
import LeadGeneration from "./pages/LeadGeneration";
import AiNewsletterAutomation from "./pages/AiNewsletterAutomation";
import AiSmartScheduling from "./pages/AiSmartScheduling";
import AiEmailValidation from "./pages/AiEmailValidation";
import AiSeoAnalyzer from "./pages/AiSeoAnalyzer";
import AiKeywordResearch from "./pages/AiKeywordResearch";
import AiCompetitorAnalysis from "./pages/AiCompetitorAnalysis";
import AiBacklinkChecker from "./pages/AiBacklinkChecker";
import AiSerpTracker from "./pages/AiSerpTracker";
import AiMetaTagGenerator from "./pages/AiMetaTagGenerator";
import AiSchemaGenerator from "./pages/AiSchemaGenerator";
import AiRobotsGenerator from "./pages/AiRobotsGenerator";
import AiSitemapGenerator from "./pages/AiSitemapGenerator";
import AiPageSpeedChecker from "./pages/AiPageSpeedChecker";
import AiSslChecker from "./pages/AiSslChecker";
import AiBrowserSecurity from "./pages/AiBrowserSecurity";
import AiPlagiarismChecker from "./pages/AiPlagiarismChecker";

// Blog posts
import Blog from "./pages/Blog";
import BewareOfScams from "./pages/blog/BewareOfScams";
import ScamAlerts from "./pages/blog/ScamAlerts";
import HideMeVpnReview from "./pages/blog/HideMeVpnReview";
import MacKeeperUltimateProtection from "./pages/blog/MacKeeperUltimateProtection";
import VipreBasicHomeProtection from "./pages/blog/VipreBasicHomeProtection";
import MicrosoftEdgeScarewareShield from "./pages/blog/MicrosoftEdgeScarewareShield";
import PersonalCybersecurity2025 from "./pages/blog/PersonalCybersecurity2025";
import SynthesysAiContent from "./pages/blog/SynthesysAiContent";
import HitmanPro from "./pages/blog/HitmanPro";
import AdvancedSystemRepair from "./pages/blog/AdvancedSystemRepair";
import VirtualDesktop from "./pages/blog/VirtualDesktop";
import EaseUsDataRecovery from "./pages/blog/EaseUsDataRecovery";
import HomeSupportPlans from "./pages/HomeSupportPlans";
import WebsiteSupportPlans from "./pages/WebsiteSupportPlans";

const queryClient = new QueryClient();

function App() {
  return (
    <QueryClientProvider client={queryClient}>
      <ThemeProvider attribute="class" defaultTheme="dark" enableSystem>
        <TooltipProvider>
          <BrowserRouter>
            <ScrollToTop />
            <GlobalPasteHandler />
            <Suspense fallback={
              <div className="min-h-screen flex items-center justify-center">
                <div className="animate-spin rounded-full h-12 w-12 border-b-2 border-primary"></div>
              </div>
            }>
              <Routes>
                <Route path="/" element={<Index />} />
                <Route path="/about-us" element={<AboutUs />} />
                <Route path="/contact-us" element={<ContactUs />} />
                <Route path="/get-quote" element={<GetQuote />} />
                <Route path="/security" element={<Security />} />
                
                <Route path="/website-security-scan" element={<WebsiteSecurityScan />} />
                <Route path="/email-breach-check" element={<EmailBreachCheck />} />
                <Route path="/browser-extension" element={<BrowserExtension />} />
                
                {/* Service Pages */}
                <Route path="/home-plans" element={<HomePlans />} />
                <Route path="/business-plans" element={<BusinessPlans />} />
                <Route path="/small-business-plans" element={<BusinessPlans />} />
                <Route path="/website-plans" element={<WebsitePlans />} />
                
                {/* Support Pages - Updated routes */}
                <Route path="/support-for-home-users" element={<HomeSupportPlans />} />
                <Route path="/home-device-support" element={<HomeDeviceSupport />} />
                <Route path="/home-plan-services" element={<HomeDeviceSupport />} />
                <Route path="/small-business-support" element={<SmallBusinessSupport />} />
                <Route path="/small-business-services" element={<SmallBusinessSupport />} />
                <Route path="/website-support" element={<WebsiteSupport />} />
                <Route path="/webpro-plans" element={<WebsiteSupportPlans />} />
                
                <Route path="/computer-selection-services" element={<ComputerSelectionServices />} />
                <Route path="/device-upgrade" element={<DeviceUpgrade />} />
                <Route path="/microsoft-365-solutions" element={<Microsoft365Solutions />} />
                <Route path="/cloud-services" element={<CloudServices />} />
                <Route path="/digital-website-solutions" element={<DigitalWebsiteSolutions />} />
                
                {/* AI Services */}
                <Route path="/ai-services" element={<AiServices />} />
                <Route path="/ai-resume-generator" element={<AiResumeGenerator />} />
                <Route path="/ai-caption-generator" element={<AiCaptionGenerator />} />
                <Route path="/ai-video-repurposing" element={<AiVideoRepurposing />} />
                <Route path="/ai-lead-generation" element={<AiLeadGeneration />} />
                <Route path="/lead-generation" element={<LeadGeneration />} />
                <Route path="/ai-newsletter-automation" element={<AiNewsletterAutomation />} />
                <Route path="/ai-smart-scheduling" element={<AiSmartScheduling />} />
                <Route path="/ai-email-validation" element={<AiEmailValidation />} />
                <Route path="/ai-seo-analyzer" element={<AiSeoAnalyzer />} />
                <Route path="/ai-keyword-research" element={<AiKeywordResearch />} />
                <Route path="/ai-competitor-analysis" element={<AiCompetitorAnalysis />} />
                <Route path="/ai-backlink-checker" element={<AiBacklinkChecker />} />
                <Route path="/ai-serp-tracker" element={<AiSerpTracker />} />
                <Route path="/ai-meta-tag-generator" element={<AiMetaTagGenerator />} />
                <Route path="/ai-schema-generator" element={<AiSchemaGenerator />} />
                <Route path="/ai-robots-generator" element={<AiRobotsGenerator />} />
                <Route path="/ai-sitemap-generator" element={<AiSitemapGenerator />} />
                <Route path="/ai-page-speed-checker" element={<AiPageSpeedChecker />} />
                <Route path="/ai-ssl-checker" element={<AiSslChecker />} />
                <Route path="/ai-browser-security" element={<AiBrowserSecurity />} />
                <Route path="/ai-plagiarism-checker" element={<AiPlagiarismChecker />} />
                
                {/* Blog Routes */}
                <Route path="/blog" element={<Blog />} />
                <Route path="/blog/beware-of-scams" element={<BewareOfScams />} />
                <Route path="/blog/scam-alerts" element={<ScamAlerts />} />
                <Route path="/blog/hidemevpn-review" element={<HideMeVpnReview />} />
                <Route path="/blog/hideme-vpn-review" element={<HideMeVpnReview />} />
                <Route path="/blog/mackeeper-ultimate-protection" element={<MacKeeperUltimateProtection />} />
                <Route path="/blog/vipre-basic-home-protection" element={<VipreBasicHomeProtection />} />
                <Route path="/blog/microsoft-edge-scareware-shield" element={<MicrosoftEdgeScarewareShield />} />
                <Route path="/blog/personal-cybersecurity-2025" element={<PersonalCybersecurity2025 />} />
                <Route path="/blog/synthesys-ai-content" element={<SynthesysAiContent />} />
                <Route path="/blog/hitman-pro" element={<HitmanPro />} />
                <Route path="/blog/hitmanpro" element={<HitmanPro />} />
                <Route path="/blog/advanced-system-repair" element={<AdvancedSystemRepair />} />
                <Route path="/blog/virtual-desktop" element={<VirtualDesktop />} />
                <Route path="/blog/easeus-data-recovery" element={<EaseUsDataRecovery />} />
                
                {/* Legal Pages */}
                <Route path="/privacy-policy" element={<PrivacyPolicy />} />
                <Route path="/terms-of-use" element={<TermsOfUse />} />
                <Route path="/refund-policy" element={<RefundPolicy />} />
                <Route path="/cookies-policy" element={<CookiesPolicy />} />
                <Route path="/dmca" element={<DMCA />} />
                <Route path="/do-not-call-policy" element={<DoNotCallPolicy />} />
                <Route path="/user-data-deletion" element={<UserDataDeletion />} />
                
                {/* 404 Route */}
                <Route path="*" element={<NotFound />} />
              </Routes>
            </Suspense>
            <TawkChatWidget />
            <FaqAiAgent />
            <Toaster />
            <Sonner />
          </BrowserRouter>
        </TooltipProvider>
      </ThemeProvider>
    </QueryClientProvider>
  );
}

export default App;
